==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/enums/SubscriptionTransitioningState.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

public enum class SubscriptionTransitioningState(
    public val javaValue: com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState> {
    Registered(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.Registered),
    Unregistered(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.Unregistered),
    Warned(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.Warned),
    Suspended(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.Suspended),
    Deleted(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.Deleted),
    WarnedToRegistered(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.WarnedToRegistered),
    WarnedToSuspended(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.WarnedToSuspended),
    WarnedToDeleted(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.WarnedToDeleted),
    WarnedToUnregistered(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.WarnedToUnregistered),
    SuspendedToRegistered(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.SuspendedToRegistered),
    SuspendedToWarned(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.SuspendedToWarned),
    SuspendedToDeleted(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.SuspendedToDeleted),
    SuspendedToUnregistered(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.SuspendedToUnregistered),
    ;

    override fun toJava(): com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState):
            SubscriptionTransitioningState =
            SubscriptionTransitioningState.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/enums/SubscriptionTransitioningState.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

public enum class SubscriptionTransitioningState(
    public val javaValue: com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState> {
    Registered(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.Registered),
    Unregistered(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.Unregistered),
    Warned(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.Warned),
    Suspended(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.Suspended),
    Deleted(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.Deleted),
    WarnedToRegistered(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.WarnedToRegistered),
    WarnedToSuspended(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.WarnedToSuspended),
    WarnedToDeleted(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.WarnedToDeleted),
    WarnedToUnregistered(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.WarnedToUnregistered),
    SuspendedToRegistered(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.SuspendedToRegistered),
    SuspendedToWarned(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.SuspendedToWarned),
    SuspendedToDeleted(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.SuspendedToDeleted),
    SuspendedToUnregistered(com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState.SuspendedToUnregistered),
    ;

    override fun toJava(): com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.providerhub.enums.SubscriptionTransitioningState): SubscriptionTransitioningState =
            SubscriptionTransitioningState.values().first { it.javaValue == javaType }
    }
}
